package App::Reg;
use strict;
use warnings;

our $VERSION = '1.1.0';

# Return positive value
1;

__END__

=head1 NAME

App::Reg - reg RegExp debugger

=head1 DESCRIPTION

App::Reg contains the L<reg> RegExp debugger. This module only contains
its version in global C<$VERSION> variable.

=head1 AUTHOR

Konrad Borowski <glitchmr@myopera.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2012 by Konrad Borowski.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.
